==> mingw-w64-clang-aarch64-flecs-docs-4.0.1-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__cpp__components.js <==
var group__cpp__components =
[
    [ "flecs::untyped_component", "structflecs_1_1untyped__component.html", [
      [ "entity", "structflecs_1_1untyped__component.html#a8baaadf7cffb365c70109d5b00e54fea", null ],
      [ "entity", "structflecs_1_1untyped__component.html#a9d2361efe2ea358b3bd0728408ced507", null ],
      [ "entity", "structflecs_1_1untyped__component.html#ac475621a5fb9513885c12474ba7ffd67", null ],
      [ "entity", "structflecs_1_1untyped__component.html#a5507fae8c3f326e957f468372b63b322", null ]
    ] ],
    [ "flecs::component< T >", "structflecs_1_1component.html", [
      [ "component", "structflecs_1_1component.html#a354267ca96c1c6ab7c75b42633e1541d", null ],
      [ "metric", "group__cpp__addons__metrics.html#gae510f6152ca2e1ed8224a679e944986e", null ],
      [ "on_add", "structflecs_1_1component.html#a703595217b5e45e17f053aeade60da3c", null ],
      [ "on_remove", "structflecs_1_1component.html#a2e628547c417f615e25344bb66aff669", null ],
      [ "on_set", "structflecs_1_1component.html#a9c6489382d8c6b7fe9d2be810852f9f7", null ],
      [ "array", "group__cpp__addons__meta.html#ga83a26164619fc68d6c5facd8b6da2671", null ],
      [ "bit", "group__cpp__addons__meta.html#gaf0f195a58a7d935aabbf5848aeaaeaf4", null ],
      [ "constant", "group__cpp__addons__meta.html#ga232842b5b739911a9124334f8e70981c", null ],
      [ "error_range", "group__cpp__addons__meta.html#gaf49405e273bee2ffa0eebb5b3f2f3644", null ],
      [ "member", "group__cpp__addons__meta.html#gad3e2eea6ea2be79ca62b92998b62ce07", null ],
      [ "member", "group__cpp__addons__meta.html#gadd5248abcf5015b6e743b226e9ae9097", null ],
      [ "member", "group__cpp__addons__meta.html#gaf19a7d2a71849b9adf2049083809d950", null ],
      [ "member", "group__cpp__addons__meta.html#ga13f4322cddb125f676dade62bdc41ed7", null ],
      [ "member", "group__cpp__addons__meta.html#ga1f1110665e3ab71a58f08ac6fcc0430f", null ],
      [ "member", "group__cpp__addons__meta.html#ga29a5211857f86f17000556ab31ae2afd", null ],
      [ "member", "group__cpp__addons__meta.html#ga77d00535e0aebd71ccafc92d29883dc6", null ],
      [ "member", "group__cpp__addons__meta.html#gad8b0f60b189fceeaf1bd435935945975", null ],
      [ "member", "group__cpp__addons__meta.html#ga6dcc60d7bcfd820d4e0e6ebc8476818f", null ],
      [ "member", "group__cpp__addons__meta.html#ga2c426e74053c6fcda37c20d0a13c2aa1", null ],
      [ "member", "group__cpp__addons__meta.html#ga38ba92b2cb86f06542229069b62a3411", null ],
      [ "member", "group__cpp__addons__meta.html#ga22af278fbce063ba13b314ccacfbba10", null ],
      [ "member", "group__cpp__addons__meta.html#ga5e43f64d820a27818a9b46514a1e3333", null ],
      [ "range", "group__cpp__addons__meta.html#gac38baa85a49b23f624cbb8490ed32503", null ],
      [ "warning_range", "group__cpp__addons__meta.html#ga57aba8f77bdfb15b7dbcc910d2a74701", null ]
    ] ],
    [ "flecs::world::component", "group__cpp__components.html#ga07c63e1c392b8c8379c3573d1417787b", null ],
    [ "flecs::world::component", "group__cpp__components.html#gafec4b378333f9542567f194a7d7e010a", null ],
    [ "flecs::reset", "group__cpp__components.html#gadcb442631ddebfb22f668a08f0694589", null ]
];

==> mingw-w64-clang-aarch64-flecs-docs-4.0.3-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__cpp__components.js <==
var group__cpp__components =
[
    [ "flecs::untyped_component", "structflecs_1_1untyped__component.html", [
      [ "entity", "structflecs_1_1untyped__component.html#a8baaadf7cffb365c70109d5b00e54fea", null ],
      [ "entity", "structflecs_1_1untyped__component.html#a9d2361efe2ea358b3bd0728408ced507", null ],
      [ "entity", "structflecs_1_1untyped__component.html#ac475621a5fb9513885c12474ba7ffd67", null ],
      [ "entity", "structflecs_1_1untyped__component.html#a5507fae8c3f326e957f468372b63b322", null ],
      [ "metric", "group__cpp__addons__metrics.html#gaad9c8dedc9972409b8fbb45bf745135e", null ],
      [ "array", "group__cpp__addons__meta.html#ga83a26164619fc68d6c5facd8b6da2671", null ],
      [ "bit", "group__cpp__addons__meta.html#gaf0f195a58a7d935aabbf5848aeaaeaf4", null ],
      [ "constant", "group__cpp__addons__meta.html#ga232842b5b739911a9124334f8e70981c", null ],
      [ "error_range", "group__cpp__addons__meta.html#gaf49405e273bee2ffa0eebb5b3f2f3644", null ],
      [ "member", "group__cpp__addons__meta.html#gad3e2eea6ea2be79ca62b92998b62ce07", null ],
      [ "member", "group__cpp__addons__meta.html#gadd5248abcf5015b6e743b226e9ae9097", null ],
      [ "member", "group__cpp__addons__meta.html#gaf19a7d2a71849b9adf2049083809d950", null ],
      [ "member", "group__cpp__addons__meta.html#ga13f4322cddb125f676dade62bdc41ed7", null ],
      [ "member", "group__cpp__addons__meta.html#ga1f1110665e3ab71a58f08ac6fcc0430f", null ],
      [ "member", "group__cpp__addons__meta.html#ga29a5211857f86f17000556ab31ae2afd", null ],
      [ "member", "group__cpp__addons__meta.html#ga77d00535e0aebd71ccafc92d29883dc6", null ],
      [ "member", "group__cpp__addons__meta.html#gad8b0f60b189fceeaf1bd435935945975", null ],
      [ "member", "group__cpp__addons__meta.html#ga6dcc60d7bcfd820d4e0e6ebc8476818f", null ],
      [ "member", "group__cpp__addons__meta.html#ga2c426e74053c6fcda37c20d0a13c2aa1", null ],
      [ "member", "group__cpp__addons__meta.html#ga38ba92b2cb86f06542229069b62a3411", null ],
      [ "member", "group__cpp__addons__meta.html#ga22af278fbce063ba13b314ccacfbba10", null ],
      [ "member", "group__cpp__addons__meta.html#ga5e43f64d820a27818a9b46514a1e3333", null ],
      [ "range", "group__cpp__addons__meta.html#gac38baa85a49b23f624cbb8490ed32503", null ],
      [ "warning_range", "group__cpp__addons__meta.html#ga57aba8f77bdfb15b7dbcc910d2a74701", null ]
    ] ],
    [ "flecs::component< T >", "structflecs_1_1component.html", [
      [ "component", "structflecs_1_1component.html#a354267ca96c1c6ab7c75b42633e1541d", null ],
      [ "constant", "structflecs_1_1component.html#addf8b318513deb4692ac369179039056", null ],
      [ "metric", "group__cpp__addons__metrics.html#gae510f6152ca2e1ed8224a679e944986e", null ],
      [ "on_add", "structflecs_1_1component.html#a703595217b5e45e17f053aeade60da3c", null ],
      [ "on_remove", "structflecs_1_1component.html#a2e628547c417f615e25344bb66aff669", null ],
      [ "on_set", "structflecs_1_1component.html#a9c6489382d8c6b7fe9d2be810852f9f7", null ],
      [ "opaque", "structflecs_1_1component.html#a3cc39417cbc52506d0f1113acf78c011", null ],
      [ "opaque", "structflecs_1_1component.html#a12d738b016f827141cf11519f66ea3bf", null ],
      [ "array", "group__cpp__addons__meta.html#ga83a26164619fc68d6c5facd8b6da2671", null ],
      [ "bit", "group__cpp__addons__meta.html#gaf0f195a58a7d935aabbf5848aeaaeaf4", null ],
      [ "constant", "group__cpp__addons__meta.html#ga232842b5b739911a9124334f8e70981c", null ],
      [ "error_range", "group__cpp__addons__meta.html#gaf49405e273bee2ffa0eebb5b3f2f3644", null ],
      [ "member", "group__cpp__addons__meta.html#gad3e2eea6ea2be79ca62b92998b62ce07", null ],
      [ "member", "group__cpp__addons__meta.html#gadd5248abcf5015b6e743b226e9ae9097", null ],
      [ "member", "group__cpp__addons__meta.html#gaf19a7d2a71849b9adf2049083809d950", null ],
      [ "member", "group__cpp__addons__meta.html#ga13f4322cddb125f676dade62bdc41ed7", null ],
      [ "member", "group__cpp__addons__meta.html#ga1f1110665e3ab71a58f08ac6fcc0430f", null ],
      [ "member", "group__cpp__addons__meta.html#ga29a5211857f86f17000556ab31ae2afd", null ],
      [ "member", "group__cpp__addons__meta.html#ga77d00535e0aebd71ccafc92d29883dc6", null ],
      [ "member", "group__cpp__addons__meta.html#gad8b0f60b189fceeaf1bd435935945975", null ],
      [ "member", "group__cpp__addons__meta.html#ga6dcc60d7bcfd820d4e0e6ebc8476818f", null ],
      [ "member", "group__cpp__addons__meta.html#ga2c426e74053c6fcda37c20d0a13c2aa1", null ],
      [ "member", "group__cpp__addons__meta.html#ga38ba92b2cb86f06542229069b62a3411", null ],
      [ "member", "group__cpp__addons__meta.html#ga22af278fbce063ba13b314ccacfbba10", null ],
      [ "member", "group__cpp__addons__meta.html#ga5e43f64d820a27818a9b46514a1e3333", null ],
      [ "range", "group__cpp__addons__meta.html#gac38baa85a49b23f624cbb8490ed32503", null ],
      [ "warning_range", "group__cpp__addons__meta.html#ga57aba8f77bdfb15b7dbcc910d2a74701", null ]
    ] ],
    [ "flecs::world::component", "group__cpp__components.html#gae215acdf24d5c8edcfc56c2c003e58f2", null ],
    [ "flecs::world::component", "group__cpp__components.html#gadf19fec48c5a4b372b9858eb5e1b6bd3", null ],
    [ "flecs::reset", "group__cpp__components.html#gadcb442631ddebfb22f668a08f0694589", null ]
];
